@@ -1,4 +1,19 @@
 """objects module tests"""
+
+# Copyright 2022 the original author or authors (i.e.: St4rG00se for Dev4py).
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from typing import Optional, Final
 
 from pytest import raises
@@ -293,7 +308,6 @@ class TestToString:
             assert result == str(None)
 
 
-
 class TestAsyncRequireNonNone:
     """async_require_non_none function tests"""
     DEFAULT_ERROR_MESSAGE: Final[str] = "None async object error"
@@ -358,7 +372,6 @@ class TestAsyncRequireNonNone:
             assert str(error.value) == message
 
 
-
 class TestAsyncRequireNonNoneElse:
     """async_require_non_none_else function tests"""
 
@@ -468,8 +481,7 @@ class TestAsyncRequireNonNoneElse:
             assert str(error.value) == TestRequireNonNone.DEFAULT_ERROR_MESSAGE
 
 
-
-class TestRequireNonNoneElseGet:
+class TestAsyncRequireNonNoneElseGet:
     """async_require_non_none_else_get function tests"""
 
     class TestNominalCase:
@@ -623,3 +635,39 @@ class TestRequireNonNoneElseGet:
                 await objects.async_require_non_none_else_get(coroutine(), None)
 
             assert str(error.value) == "Supplier cannot be None"
+
+
+class TestToNone:
+    """to_none function tests"""
+
+    class TestNominalCase:
+
+        def test__should__return_none(self) -> None:
+            """Should return None whatever the parameters"""
+            # GIVEN / WHEN / THEN
+            assert objects.to_none(1, 'a', named_param=True) is None
+
+
+class TestToSelf:
+    """to_self function tests"""
+
+    class TestNominalCase:
+
+        def test_existing_parameter__should__return_given_parameter(self) -> None:
+            """Should return the given parameter"""
+            # GIVEN
+            obj: str = "A test str"
+
+            # WHEN
+            result: str = objects.to_self(obj)
+
+            # THEN
+            assert result == obj
+
+        def test_none_parameter__should__return_none(self) -> None:
+            """Should return the given parameter"""
+            # GIVEN / WHEN
+            result: None = objects.to_self(None)
+
+            # THEN
+            assert result is None
